@@ -1,4 +1,6 @@
 from django.db.models import Func
+from django.contrib.postgres.operations import CreateExtension
+
 
 class Levenshtein(Func):
     """ For use of the levenshtein algorithm with a PostgreSQL Database """
@@ -11,3 +13,8 @@ class Levenshtein(Func):
             search_term=search_term,
             **extras
         )
+
+
+class FuzzystrExtension(CreateExtension):
+    def __init__(self):
+        self.name = 'fuzzystrmatch'
